@@ -1,4 +1,4 @@
-/*  Copyright (C) 2024 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2025 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -1324,6 +1324,9 @@ int server_reload(server_t *server, reload_t mode)
 			return ret;
 		}
 
+		ATOMIC_SET(server->stats.tcp_io_timeout, 0);
+		ATOMIC_SET(server->stats.tcp_idle_timeout, 0);
+
 		conf_activate_modules(new_conf, server, NULL, new_conf->query_modules,
 		                      &new_conf->query_plan);
 	}
@@ -1585,8 +1588,10 @@ void server_update_zones(conf_t *conf, server_t *server, reload_t mode)
 	}
 
 	/* Suspend adding events to worker pool queue, wait for queued events. */
+	log_debug("suspending zone events");
 	evsched_pause(&server->sched);
 	worker_pool_wait(server->workers);
+	log_debug("suspended zone events");
 
 	/* Reload zone database and free old zones. */
 	zonedb_reload(conf, server, mode);
@@ -1599,6 +1604,7 @@ void server_update_zones(conf_t *conf, server_t *server, reload_t mode)
 	if (server->zone_db) {
 		knot_zonedb_foreach(server->zone_db, zone_events_start);
 	}
+	log_debug("resumed zone events");
 }
 
 size_t server_cert_pin(server_t *server, uint8_t *out, size_t out_size)
