@@ -92,9 +92,9 @@ static void print_help(void)
 	       "                 (syntax: set <key_spec> <attribute_name>=<value>...)\n"
 	       "\n"
 	       "Keystore commands:\n"
-	       "  keystore_test   Conduct some tests on the specified keystore.\n"
+	       "  keystore-test   Conduct some tests on the specified keystore.\n"
 	       "                   Use a configured keystore id or '-' for the default.\n"
-	       "  keystore_bench  Conduct a signing benchmark for each supported algorithm.\n"
+	       "  keystore-bench  Conduct a signing benchmark for each supported algorithm.\n"
 	       "                   Use a configured keystore id or '-' for the default.\n"
 	       "                   (syntax: keystore_bench [<num_threads>])\n"
 	       "\n"
